eegdash.features.utils
======================

.. automodule:: eegdash.features.utils
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

   
   .. rubric:: Functions

   .. autosummary::
   
      delayed
      extract_features
      fit_feature_extractors
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseConcatDataset
      Callable
      DataLoader
      EEGWindowsDataset
      FeatureExtractor
      FeaturesConcatDataset
      FeaturesDataset
      Parallel
      WindowsDataset
      tqdm
   
